<div class="repo">
  {%- if config.repo_name %}
    <div class="link">
      {%- if config.repo_name == 'GitHub' %}
        <a href="{{ config.repo_url }}" class="fa fa-github"> GitHub</a>
      {%- elif config.repo_name == 'Bitbucket' %}
        <a href="{{ config.repo_url }}" class="icon icon-bitbucket"> BitBucket</a>
      {%- elif config.repo_name == 'GitLab' %}
        <a href="{{ config.repo_url }}" class="icon icon-gitlab"> GitLab</a>
      {%- endif %}
    </div>
  {%- endif %}
  {%- if page.previous_page %}
    <div class="previous"><a href="{{ page.previous_page.url|url }}">&laquo; Anterior</a></div>
  {%- endif %}
  {%- if page.next_page %}
    <div class="next"><a href="{{ page.next_page.url|url }}">Siguiente &raquo;</a></div>
  {%- endif %}
</div>
