{% extends "base.html" %}

{% block content %}

  <h1 id="search">Resultados de búsqueda</h1>

  <form id="content_search" action="search.html">
    <span role="status" aria-live="polite" class="ui-helper-hidden-accessible"></span>
    <input name="q" id="maedocs-search-query" type="text" class="search_input search-query ui-autocomplete-input" placeholder="Search the Docs" autocomplete="off" autofocus title="Type search term here">
  </form>

  <div id="maedocs-search-results" class="search-results">
    Buscando...
  </div>

{% endblock %}
